@@ -181,6 +181,8 @@ struct thread_options {
 	double zipf_theta;
 	double pareto_h;
 
+	unsigned int random_generator;
+
 	unsigned int hugepage_size;
 	unsigned int rw_min_bs;
 	unsigned int thinktime;
@@ -307,11 +309,34 @@ struct thread_options {
 	unsigned int sync_file_range;
 };
 
+enum {
+	TD_F_VER_BACKLOG	= 1,
+	TD_F_TRIM_BACKLOG	= 2,
+	TD_F_READ_IOLOG		= 4,
+	TD_F_REFILL_BUFFERS	= 8,
+	TD_F_SCRAMBLE_BUFFERS	= 16,
+	TD_F_VER_NONE		= 32,
+	TD_F_PROFILE_OPS	= 64,
+};
+
+enum {
+	FIO_RAND_BS_OFF		= 0,
+	FIO_RAND_VER_OFF,
+	FIO_RAND_MIX_OFF,
+	FIO_RAND_FILE_OFF,
+	FIO_RAND_BLOCK_OFF,
+	FIO_RAND_FILE_SIZE_OFF,
+	FIO_RAND_TRIM_OFF,
+	FIO_RAND_BUF_OFF,
+	FIO_RAND_NR_OFFS,
+};
+
 /*
  * This describes a single thread/process executing a fio job.
  */
 struct thread_data {
 	struct thread_options o;
+	unsigned long flags;
 	void *eo;
 	char verror[FIO_VERROR_SIZE];
 	pthread_t thread;
@@ -366,7 +391,7 @@ struct thread_data {
 
 	char *sysfs_root;
 
-	unsigned long rand_seeds[8];
+	unsigned long rand_seeds[FIO_RAND_NR_OFFS];
 
 	union {
 		os_random_state_t bsrange_state;
@@ -573,6 +598,7 @@ extern char *job_section;
 extern int fio_gtod_offload;
 extern int fio_gtod_cpu;
 extern enum fio_cs fio_clock_source;
+extern int fio_clock_source_set;
 extern int warnings_fatal;
 extern int terse_version;
 extern int is_backend;
@@ -588,11 +614,6 @@ static inline void fio_ro_check(struct thread_data *td, struct io_u *io_u)
 	assert(!(io_u->ddir == DDIR_WRITE && !td_write(td)));
 }
 
-#define BLOCKS_PER_MAP		(8 * sizeof(unsigned long))
-#define TO_MAP_BLOCK(f, b)	(b)
-#define RAND_MAP_IDX(f, b)	(TO_MAP_BLOCK(f, b) / BLOCKS_PER_MAP)
-#define RAND_MAP_BIT(f, b)	(TO_MAP_BLOCK(f, b) & (BLOCKS_PER_MAP - 1))
-
 #define REAL_MAX_JOBS		2048
 
 static inline enum error_type_bit td_error_type(enum fio_ddir ddir, int err)
@@ -686,8 +707,8 @@ enum {
 	TD_NOT_CREATED = 0,
 	TD_CREATED,
 	TD_INITIALIZED,
-	TD_SETTING_UP,
 	TD_RAMP,
+	TD_SETTING_UP,
 	TD_RUNNING,
 	TD_PRE_READING,
 	TD_VERIFYING,
@@ -827,4 +848,9 @@ enum {
 	FIO_RAND_DIST_PARETO,
 };
 
+enum {
+	FIO_RAND_GEN_TAUSWORTHE = 0,
+	FIO_RAND_GEN_LFSR,
+};
+
 #endif
