@@ -1,7 +1,7 @@
 #ifndef FIO_IOENGINE_H
 #define FIO_IOENGINE_H
 
-#define FIO_IOOPS_VERSION	13
+#define FIO_IOOPS_VERSION	14
 
 enum {
 	IO_U_F_FREE		= 1 << 0,
@@ -11,6 +11,7 @@ enum {
 	IO_U_F_BUSY_OK		= 1 << 4,
 	IO_U_F_TRIMMED		= 1 << 5,
 	IO_U_F_BARRIER		= 1 << 6,
+	IO_U_F_VER_LIST		= 1 << 7,
 };
 
 /*
@@ -44,12 +45,16 @@ struct io_u {
 	struct timeval start_time;
 	struct timeval issue_time;
 
+	struct fio_file *file;
+	unsigned int flags;
+	enum fio_ddir ddir;
+
 	/*
 	 * Allocated/set buffer and length
 	 */
-	void *buf;
 	unsigned long buflen;
 	unsigned long long offset;
+	void *buf;
 
 	/*
 	 * Initial seed for generating the buffer contents
@@ -72,8 +77,6 @@ struct io_u {
 	unsigned int resid;
 	unsigned int error;
 
-	enum fio_ddir ddir;
-
 	/*
 	 * io engine private data
 	 */
@@ -83,10 +86,6 @@ struct io_u {
 		void *engine_data;
 	};
 
-	unsigned int flags;
-
-	struct fio_file *file;
-
 	struct flist_head list;
 
 	/*
@@ -121,6 +120,9 @@ struct ioengine_ops {
 	int (*open_file)(struct thread_data *, struct fio_file *);
 	int (*close_file)(struct thread_data *, struct fio_file *);
 	int (*get_file_size)(struct thread_data *, struct fio_file *);
+	void (*terminate)(struct thread_data *);
+	int (*io_u_init)(struct thread_data *, struct io_u *);
+	void (*io_u_free)(struct thread_data *, struct io_u *);
 	int option_struct_size;
 	struct fio_option *options;
 	void *data;
@@ -135,10 +137,9 @@ enum fio_ioengine_flags {
 	FIO_NODISKUTIL  = 1 << 4,	/* diskutil can't handle filename */
 	FIO_UNIDIR	= 1 << 5,	/* engine is uni-directional */
 	FIO_NOIO	= 1 << 6,	/* thread does only pseudo IO */
-	FIO_SIGTERM	= 1 << 7,	/* needs SIGTERM to exit */
-	FIO_PIPEIO	= 1 << 8,	/* input/output no seekable */
-	FIO_BARRIER	= 1 << 9,	/* engine supports barriers */
-	FIO_MEMALIGN	= 1 << 10,	/* engine wants aligned memory */
+	FIO_PIPEIO	= 1 << 7,	/* input/output no seekable */
+	FIO_BARRIER	= 1 << 8,	/* engine supports barriers */
+	FIO_MEMALIGN	= 1 << 9,	/* engine wants aligned memory */
 };
 
 /*
@@ -176,7 +177,7 @@ extern int __must_check io_u_queued_complete(struct thread_data *, int, unsigned
 extern void io_u_queued(struct thread_data *, struct io_u *);
 extern void io_u_log_error(struct thread_data *, struct io_u *);
 extern void io_u_mark_depth(struct thread_data *, unsigned int);
-extern void io_u_fill_buffer(struct thread_data *td, struct io_u *, unsigned int);
+extern void io_u_fill_buffer(struct thread_data *td, struct io_u *, unsigned int, unsigned int);
 void io_u_mark_complete(struct thread_data *, unsigned int);
 void io_u_mark_submit(struct thread_data *, unsigned int);
 
